@@ -9,13 +9,13 @@ use base 'Exporter';
 our @EXPORT_OK = qw/encode decode/;
 
 use version;
-our $VERSION = 'v0.999.3'; # TRIAL
+our $VERSION = 'v0.999.4'; # TRIAL
 
 use Carp;
 use Config;
 use Scalar::Util qw/blessed/;
 
-use Moo;
+use Moo 2.002004; # safer generated code
 use Module::Runtime qw/require_module/;
 use BSON::Types (); # loads types for extjson inflation
 use boolean;
@@ -617,7 +617,7 @@ BSON - BSON serialization and deserialization
 
 =head1 VERSION
 
-version v0.999.3
+version v0.999.4
 
 =head1 SYNOPSIS
 
